#
# Global data frames
#
weather = NULL           # Weather data
W = NULL                 # Hive data on original time resolution
WD = NULL                # Hive data summarized daily

#
# Functions
#

reorder_levels = function(the_factor, new_order) {
  factor(the_factor,levels(the_factor)[new_order])
}
reorder_levels = function(the_factor, new_order) {
  factor(the_factor,levels(the_factor)[new_order])
}
# x = factor(sample(letters[1:5],100, replace=TRUE))
# x
# x = reorder_levels(x, c(4,5,1:3))
# x

# For each hive finds the min and max rate of weight change on a certain date;
# returns a data frame wint min and max info
max_weight_rate = function(date) {
  ddply(subset_date(W, date), .(Hive), summarize, 
    MinWeightRate = min(WeightRate), 
    MaxWeightRate = max(WeightRate), 
    MinDateTime = DateTime[which.min(WeightRate)],
    MaxDateTime = DateTime[which.max(WeightRate)])
}

# Subsets on a certain date the weight gain on related information on a certain date;
# returns a data frame with the selected info
weight_gain = function(date) {
  subset_date(WD, date)[c("Date","Hive","WeightGain", "WeightCorrected", "Rain")]
}

# Returns the n right-most characters in text
right = function(text, n) {
  s = as.character(text)
  substr(s, nchar(s) - (n-1), nchar(s))
}
    
#
# Main
#

# Data set information
az2014 = 
list(location             = "Santa Rita",
     latitude             = 31.82138, 
     longitude            = -110.86613, 
     time_zone            = -7,
     weight_file          = "input/hive-weight-az-2014.txt", 
     weight_file_date     = "dmyHM",
     weather_file         = "input/weather.txt", 
     weather_file_date    = "dmyHM",
     exclude_dates        = dmy(c("27/7/2014", "17/9/2014")))
     
az2015 = 
list(location             = "Santa Rita",
     latitude             = 31.82138, 
     longitude            = -110.86613, 
     time_zone            = -7,
     weight_file          = "input/hive-weight-az-2015.txt", 
     weight_file_date     = "mdyHM",
     weather_file         = "input/weather.txt", 
     weather_file_date    = "dmyHM",
     exclude_dates        = dmy(c("30/6/2015", "28/7/2015", "31/7/2015", "9/8/2015", "29/8/2015")))

     
# Read files
X = bc_load(list(az2014, az2015))
W <<- X[[1]]
WD <<- X[[2]]

# Add weight gain of previous date
prev_weight_gain = function(hive, date) {
  y = subset_hive_date(WD, hive, date-1)
  if (nrow(y)==0) NA else y$WeightGain
}
WD = ddply(WD, .(Hive,Date), mutate, WeightGainPrev= prev_weight_gain(Hive, Date))

# Add treatments
WD$Period = "Before"
f = function(x) {
  WD$Period[WD$Year==x$Year & WD$Date>x$TreatmentDate] <<- "After"
}
d_ply(treatment_dates, .(Year), f)
WD$Period = factor(WD$Period)

# Remove daily data when disturbed by intervention
interventions = bc_read_interventions("input/interventions.txt", "mdy")
WD = subset(WD, !(Date %in% c(interventions$Date,
            dmy("22/04/2014"),   # WeightGain < -2; unexplained 
            dmy("12/07/2014"),   # SlopeMidnight > 0.5; rain, likely
            dmy("21/10/2014"),   # Extreme WeightSlack
            dmy("07/08/2015"),   # missing intervention
            dmy("14/07/2016")    # missing intervention
            )))
# Missing interventions
WD = subset(WD, !(Hive=="H108" & Date==dmy("23/6/2015")))
WD = subset(WD, !(Hive=="H108" & Date==dmy("24/6/2015")))
WD = subset(WD, !(Hive=="H108" & Date==dmy("25/6/2015")))
WD = subset(WD, !(Hive=="H103" & Date==dmy("5/8/2015")))
WD = subset(WD, !(Hive=="H103" & Date==dmy("5/8/2015")))
# Rain
WD = subset(WD, Date!=dmy("15/07/2014"))
WD = subset(WD, Date!=dmy("27/07/2014"))
WD = subset(WD, Date!=dmy("17/09/2014"))
WD = subset(WD, Date!=dmy("09/06/2015"))
WD = subset(WD, Date!=dmy("30/06/2015"))
WD = subset(WD, Date!=dmy("06/08/2015"))
WD = subset(WD, Date!=dmy("08/08/2015"))
# Extreme WeightSpan
WD = subset(WD, !(Hive=="hive73" & Date==dmy("22/5/2014"))) 
WD = subset(WD, !(Hive=="H113" & Date==dmy("11/6/2015"))) 
WD = subset(WD, !(Hive=="H106" & Date==dmy("07/5/2015"))) 
WD = subset(WD, !(Hive=="H106" & Date==dmy("13/5/2015"))) 
# WeightGain<-2
WD = subset(WD, !(Hive=="hive63" & Date==dmy("26/7/2014"))) 
WD = subset(WD, !(Hive=="hive69" & Date==dmy("20/8/2014"))) 
WD = subset(WD, !(Hive=="hive69" & Date==dmy("23/8/2014"))) 

save(W, file="output/W.Rdata")
save(WD, file="output/WD.Rdata")
save(weather, file="output/weather.Rdata")

