# Extracts slopes from a segmented model;
# returns a data frame with a row for each segment detailing where the segments goes from and to, and the slope
extract_slopes = function(model) {
  best_model = model$Model.BestModel 
  if (is.null(best_model)) return(NULL)
  segments = extract_segments(best_model)
  breaks = segments$Breaks$Value
  slope_values = segments$Lines$Slope
  from = 0
  slps = data.frame()
  n = length(breaks)
  # Loop through segments
  for (i in 1:n) {
    to = breaks[i] 
    slps = rbind(slps, c(i, from, to, slope_values[i]))
    from = to
  }

  slps = rbind(slps, c(n+1, from, final_hour(model$Hive,model$Date), slope_values[n+1]))
  slps = data.frame(slps)
  colnames(slps) = c("Segment", "From", "To", "Slope")
  
  mutate(slps,   
    R2=summary(best_model)$r.squared,
    Hive=model$Hive, 
    Date=model$Date, 
    NumBreaks = n
  )
}
  
#
# Main
#

# Load SLR models
print(getwd())
load("output/slr_models.Rdata")

# Extract the slopes and breakpoints for the best SLR model
best_slr = ldply(slr_models, extract_slopes)[,-1]

# Save best SLR models
save(best_slr, file="output/best_slr.Rdata")
