#
# Functions
#

enumerate_categories = function() {
  x = summary(canyons$Category)
  M = data.frame(factor(names(x)), Count=x)
  colnames(M)[1] = "Code"
  M
}

slr_overview_plot = function() {
  # Enumerate categories
  categories = enumerate_categories()
  num_categories = nrow(categories)

  # Merge with segment lines
  seg = read.table("input/segment-lines.txt", header=TRUE)
  seg$Code = factor(seg$Code)
  seg$Note = as.character(seg$Note)
  seg$Note[seg$Note=="x"] = " "
  seg = join(categories, seg, by="Code", type="left")
  seg = seg[order(seg$Count, decreasing=TRUE),]
  rownames(seg) = NULL

  #Adjust coordinates
  y_scaling = 35
  seg$Order = num_categories - floor((as.numeric(rownames(seg))-1)/5) - 1
  seg$Y = seg$Y + y_scaling*seg$Order
  seg$LabelY = 6 + y_scaling*seg$Order
  
  #Split into two columns
  x_offset = 14
  half = ceiling(num_categories/2)
  ix_left  = 1:(5*half)
  ix_right = (5*half + 1):(5*num_categories)
  
  # Shift left
  seg$X[ix_right] = seg$X[ix_right] + x_offset
  seg$LabelX = 6.5
  seg$LabelX[ix_right] = seg$LabelX[ix_right] + x_offset
  
  # Shift up
  seg$Y[ix_right] = seg$Y[ix_right] + y_scaling*half
  seg$LabelY[ix_right] = seg$LabelY[ix_left[1:length(ix_right)]]
  
  # Plot
  point_size = 2
  line_size = 1
  ggplot(seg, aes(x=X, y=Y, group=Code)) +
    geom_line(size=line_size) + 
    geom_line(data=subset(seg, BCline==1), colour="red", size=line_size) +
    geom_point(data=subset(seg, BC==1), colour="red", size=point_size) +
    geom_point(data=subset(seg, BC==0), size=point_size) +
    geom_text(hjust=0, size=5, aes(x=LabelX, y=LabelY, label=Count)) +
    geom_text(hjust=0, size=4.5, aes(x=LabelX+1.7, y=LabelY+3.9, label=Note)) +
    scale_x_continuous(limits=c(1,25)) +
    labs(x="", y="") + 
    theme(panel.background=element_blank(),
          axis.line=element_blank(),
          axis.ticks=element_blank(),
          axis.text=element_blank(),
          legend.position="none") 
    
}

#
# Main
#

load("output/canyons.Rdata")
G = slr_overview_plot()

# Show on screen and PDF
windows(3.8,6)
print(G)
pdf("output/fig3.pdf", 5.7, 9)
print(G)
dev.off()

