night_plot = function() {
  M = with(WD_canyons, data.frame(
    X    = NightFrom-Sunrise, 
    Y    = 0, 
    Xend = NightTo-Sunrise, 
    Yend = (NightFrom-NightTo)*(-NightSlope)
  ))

  P = ggplot(M, aes(colour=X)) +
    geom_segment(aes(x=X, y=Y, xend=Xend, yend=Yend), alpha=0.4) +
    geom_point(aes(x=Xend, y=Yend), size=0.9) + 
    theme(panel.background = element_blank(),
          axis.line = element_line(colour = "black"),
          legend.position = "none") +
    scale_x_continuous(breaks=-12:12, limits=c(-7,4)) +
    scale_y_continuous(breaks=(-10:10)/10) +
    geom_vline(xintercept=0, colour="orange", size=2, alpha=0.5) +
    labs(x="", y="Weight (kg)") +
    theme(axis.text=element_text(size=14),
          axis.title=element_text(size=14,face="bold")
         ) +
    scale_colour_distiller(type="qual", palette=6, direction=1)
}

canyons_plot = function() {  
  M = with(WD_canyons, data.frame(
    X    = CanyonHourBegin-Sunrise, 
    Y    = 0, 
    Xend = CanyonHour-Sunrise, 
    Yend = -CanyonDepth
  ))
  
  ggplot(M, aes(colour=Xend)) +
    geom_segment(aes(x=X, y=Y, xend=Xend, yend=Yend), alpha=0.4) +
    geom_point(aes(x=Xend, y=Yend), size=0.9) + 
    theme(panel.background = element_blank(),
          axis.line = element_line(colour = "black"),
          legend.position = "none") +
    scale_x_continuous(breaks=-12:12, limits=c(-7,4)) +
    scale_y_continuous(breaks=(-10:10)/10) +
    geom_vline(xintercept=0, colour="orange", size=2, alpha=0.5) +
    scale_colour_distiller(type="qual", palette=6, direction=-1) +
    labs(x="Hours from sunrise", y="Weight (kg)") +
    theme(axis.text=element_text(size=14),
      axis.title=element_text(size=14,face="bold")
    )
}

#
# Main
#

load("output/WD_canyons.Rdata")
G = grid.arrange(night_plot(), canyons_plot(), ncol=1)

# Show on screen and PDF
windows(10,12)
grid.draw(G)

pdf("output/fig4.pdf", 8, 7)
grid.draw(G)
dev.off()

