load("output/lme_design.Rdata")
load("output/lme_models.Rdata")

#
# Functions
#

get_phi_n = function(model) {
  x = model[[1]]$model$corStruct
  data.frame(Phi = round(coef(x,unconstrained=FALSE), 2), N = nrow(model[[1]]$data))
}

get_fixed = function(model) {
  x = summary(model[[1]])$tTable
  data.frame(Variable=attr(model[[1]],"Variable"), Year=attr(model[[1]], "Year"), Treatment=rownames(x), round(x[,c(1,2,5)], 4))
}

table1 = function() {
  M = cbind(lme_design, ldply(lme_models, get_phi_n))  
  data.frame(
    Variable = M$Variable[2*(1:3)],
    N2014 = M$N[2*(1:3)-1],
    N2015 = M$N[2*(1:3)],
    Phi2014 = M$Phi[2*(1:3)-1],
    Phi2015 = M$Phi[2*(1:3)]
  )
}

table2 = function() {
M = join(lme_design, ldply(lme_models, get_fixed))
M = subset(M, str_detect(Treatment, ":PeriodAfter"))
rownames(M) = {}
ix2014 = c(1,NA,2, 6,NA,7, 11,NA,12)
ix2015 = c(3:5, 8:10, 13:15)
data.frame(
  Variable = M$Variable[c(1:3, 6:8, 11:13)],
  Treatment = rep(c("Low", "Medium", "High"),3),
  Coef2014 = round(M$Value[ix2014],3),
  SE2014   = round(M$Std.Error[ix2014],3),
  P2014    = round(M$p.value[ix2014],3),
  Coef2015 = round(M$Value[ix2015],3),
  SE2015   = round(M$Std.Error[ix2015],3),
  P2015    = round(M$p.value[ix2015],3)
)
}

#
# Main
#

print(table1())
print(table2())

write.table(table1(), "output/table1.txt", quote=FALSE, sep="\t", row.names=FALSE)
write.table(table2(), "output/table2.txt", quote=FALSE, sep="\t", row.names=FALSE)

